# Generated by Django 3.2.3 on 2022-08-22 19:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('openlxp_notifications', '0002_rename_logs_type_emailconfiguration_content_type'),
    ]

    operations = [
        migrations.AddField(
            model_name='emailconfiguration',
            name='Banner',
            field=models.ImageField(default='banner.jpg', help_text='add logo image', upload_to='banner'),
        ),
    ]
